@@ -1,4 +1,3 @@
-from sqlalchemy.exc import NoSuchTableError
 from sqlalchemy import schema as sa_schema, types as sqltypes
 import logging
 from .. import compat
@@ -8,6 +7,7 @@ from sqlalchemy.util import OrderedSet
 
 log = logging.getLogger(__name__)
 
+
 def _run_filters(object_, name, type_, reflected, compare_to, object_filters):
     for fn in object_filters:
         if not fn(object_, name, type_, reflected, compare_to):
@@ -15,6 +15,7 @@ def _run_filters(object_, name, type_, reflected, compare_to, object_filters):
     else:
         return True
 
+
 def _compare_tables(conn_table_names, metadata_table_names,
                     object_filters,
                     inspector, metadata, diffs, autogen_context):
@@ -35,26 +36,27 @@ def _compare_tables(conn_table_names, metadata_table_names,
     # as "schemaname.tablename" or just "tablename", create a new lookup
     # which will match the "non-default-schema" keys to the Table object.
     tname_to_table = dict(
-                        (
-                            no_dflt_schema,
-                            metadata.tables[sa_schema._get_table_key(tname, schema)]
-                        )
-                        for no_dflt_schema, (schema, tname) in zip(
-                                    metadata_table_names_no_dflt_schema,
-                                    metadata_table_names)
-                        )
+        (
+            no_dflt_schema,
+            metadata.tables[sa_schema._get_table_key(tname, schema)]
+        )
+        for no_dflt_schema, (schema, tname) in zip(
+            metadata_table_names_no_dflt_schema,
+            metadata_table_names)
+    )
     metadata_table_names = metadata_table_names_no_dflt_schema
 
     for s, tname in metadata_table_names.difference(conn_table_names):
         name = '%s.%s' % (s, tname) if s else tname
         metadata_table = tname_to_table[(s, tname)]
-        if _run_filters(metadata_table, tname, "table", False, None, object_filters):
+        if _run_filters(
+                metadata_table, tname, "table", False, None, object_filters):
             diffs.append(("add_table", metadata_table))
             log.info("Detected added table %r", name)
             _compare_indexes_and_uniques(s, tname, object_filters,
-                    None,
-                    metadata_table,
-                    diffs, autogen_context, inspector)
+                                         None,
+                                         metadata_table,
+                                         diffs, autogen_context, inspector)
 
     removal_metadata = sa_schema.MetaData()
     for s, tname in conn_table_names.difference(metadata_table_names):
@@ -85,35 +87,40 @@ def _compare_tables(conn_table_names, metadata_table_names,
         metadata_table = tname_to_table[(s, tname)]
         conn_table = existing_metadata.tables[name]
 
-        if _run_filters(metadata_table, tname, "table", False, conn_table, object_filters):
+        if _run_filters(
+                metadata_table, tname, "table", False,
+                conn_table, object_filters):
             _compare_columns(s, tname, object_filters,
-                    conn_table,
-                    metadata_table,
-                    diffs, autogen_context, inspector)
+                             conn_table,
+                             metadata_table,
+                             diffs, autogen_context, inspector)
             _compare_indexes_and_uniques(s, tname, object_filters,
-                    conn_table,
-                    metadata_table,
-                    diffs, autogen_context, inspector)
+                                         conn_table,
+                                         metadata_table,
+                                         diffs, autogen_context, inspector)
 
     # TODO:
     # table constraints
     # sequences
 
+
 def _make_index(params, conn_table):
     return sa_schema.Index(
-            params['name'],
-            *[conn_table.c[cname] for cname in params['column_names']],
-            unique=params['unique']
+        params['name'],
+        *[conn_table.c[cname] for cname in params['column_names']],
+        unique=params['unique']
     )
 
+
 def _make_unique_constraint(params, conn_table):
     return sa_schema.UniqueConstraint(
-            *[conn_table.c[cname] for cname in params['column_names']],
-            name=params['name']
+        *[conn_table.c[cname] for cname in params['column_names']],
+        name=params['name']
     )
 
+
 def _compare_columns(schema, tname, object_filters, conn_table, metadata_table,
-                                diffs, autogen_context, inspector):
+                     diffs, autogen_context, inspector):
     name = '%s.%s' % (schema, tname) if schema else tname
     metadata_cols_by_name = dict((c.name, c) for c in metadata_table.c)
     conn_col_names = dict((c.name, c) for c in conn_table.c)
@@ -121,7 +128,7 @@ def _compare_columns(schema, tname, object_filters, conn_table, metadata_table,
 
     for cname in metadata_col_names.difference(conn_col_names):
         if _run_filters(metadata_cols_by_name[cname], cname,
-                                "column", False, None, object_filters):
+                        "column", False, None, object_filters):
             diffs.append(
                 ("add_column", schema, tname, metadata_cols_by_name[cname])
             )
@@ -129,7 +136,7 @@ def _compare_columns(schema, tname, object_filters, conn_table, metadata_table,
 
     for cname in set(conn_col_names).difference(metadata_col_names):
         if _run_filters(conn_table.c[cname], cname,
-                                "column", True, None, object_filters):
+                        "column", True, None, object_filters):
             diffs.append(
                 ("remove_column", schema, tname, conn_table.c[cname])
             )
@@ -139,28 +146,31 @@ def _compare_columns(schema, tname, object_filters, conn_table, metadata_table,
         metadata_col = metadata_cols_by_name[colname]
         conn_col = conn_table.c[colname]
         if not _run_filters(
-                    metadata_col, colname, "column", False, conn_col, object_filters):
+                metadata_col, colname, "column", False,
+                conn_col, object_filters):
             continue
         col_diff = []
         _compare_type(schema, tname, colname,
-            conn_col,
-            metadata_col,
-            col_diff, autogen_context
-        )
+                      conn_col,
+                      metadata_col,
+                      col_diff, autogen_context
+                      )
         _compare_nullable(schema, tname, colname,
-            conn_col,
-            metadata_col.nullable,
-            col_diff, autogen_context
-        )
+                          conn_col,
+                          metadata_col.nullable,
+                          col_diff, autogen_context
+                          )
         _compare_server_default(schema, tname, colname,
-            conn_col,
-            metadata_col,
-            col_diff, autogen_context
-        )
+                                conn_col,
+                                metadata_col,
+                                col_diff, autogen_context
+                                )
         if col_diff:
             diffs.append(col_diff)
 
+
 class _constraint_sig(object):
+
     def __eq__(self, other):
         return self.const == other.const
 
@@ -170,6 +180,7 @@ class _constraint_sig(object):
     def __hash__(self):
         return hash(self.const)
 
+
 class _uq_constraint_sig(_constraint_sig):
     is_index = False
     is_unique = True
@@ -183,6 +194,7 @@ class _uq_constraint_sig(_constraint_sig):
     def column_names(self):
         return [col.name for col in self.const.columns]
 
+
 class _ix_constraint_sig(_constraint_sig):
     is_index = True
 
@@ -196,20 +208,24 @@ class _ix_constraint_sig(_constraint_sig):
     def column_names(self):
         return _get_index_column_names(self.const)
 
+
 def _get_index_column_names(idx):
     if compat.sqla_08:
         return [getattr(exp, "name", None) for exp in idx.expressions]
     else:
         return [getattr(col, "name", None) for col in idx.columns]
 
+
 def _compare_indexes_and_uniques(schema, tname, object_filters, conn_table,
-            metadata_table, diffs, autogen_context, inspector):
+                                 metadata_table, diffs,
+                                 autogen_context, inspector):
 
     is_create_table = conn_table is None
 
     # 1a. get raw indexes and unique constraints from metadata ...
-    metadata_unique_constraints = set(uq for uq in metadata_table.constraints
-            if isinstance(uq, sa_schema.UniqueConstraint)
+    metadata_unique_constraints = set(
+        uq for uq in metadata_table.constraints
+        if isinstance(uq, sa_schema.UniqueConstraint)
     )
     metadata_indexes = set(metadata_table.indexes)
 
@@ -222,7 +238,7 @@ def _compare_indexes_and_uniques(schema, tname, object_filters, conn_table,
         if hasattr(inspector, "get_unique_constraints"):
             try:
                 conn_uniques = inspector.get_unique_constraints(
-                                                tname, schema=schema)
+                    tname, schema=schema)
                 supports_unique_constraints = True
             except NotImplementedError:
                 pass
@@ -234,60 +250,62 @@ def _compare_indexes_and_uniques(schema, tname, object_filters, conn_table,
         # 2. convert conn-level objects from raw inspector records
         # into schema objects
         conn_uniques = set(_make_unique_constraint(uq_def, conn_table)
-                                        for uq_def in conn_uniques)
+                           for uq_def in conn_uniques)
         conn_indexes = set(_make_index(ix, conn_table) for ix in conn_indexes)
 
     # 3. give the dialect a chance to omit indexes and constraints that
     # we know are either added implicitly by the DB or that the DB
     # can't accurately report on
     autogen_context['context'].impl.\
-                                correct_for_autogen_constraints(
-                                        conn_uniques, conn_indexes,
-                                        metadata_unique_constraints,
-                                        metadata_indexes
-                                )
+        correct_for_autogen_constraints(
+            conn_uniques, conn_indexes,
+            metadata_unique_constraints,
+            metadata_indexes)
 
     # 4. organize the constraints into "signature" collections, the
     # _constraint_sig() objects provide a consistent facade over both
     # Index and UniqueConstraint so we can easily work with them
     # interchangeably
     metadata_unique_constraints = set(_uq_constraint_sig(uq)
-                                    for uq in metadata_unique_constraints
-                                    )
+                                      for uq in metadata_unique_constraints
+                                      )
 
     metadata_indexes = set(_ix_constraint_sig(ix) for ix in metadata_indexes)
 
-    conn_unique_constraints = set(_uq_constraint_sig(uq) for uq in conn_uniques)
+    conn_unique_constraints = set(
+        _uq_constraint_sig(uq) for uq in conn_uniques)
 
     conn_indexes = set(_ix_constraint_sig(ix) for ix in conn_indexes)
 
     # 5. index things by name, for those objects that have names
     metadata_names = dict(
-                        (c.name, c) for c in
-                        metadata_unique_constraints.union(metadata_indexes)
-                        if c.name is not None)
+        (c.name, c) for c in
+        metadata_unique_constraints.union(metadata_indexes)
+        if c.name is not None)
 
     conn_uniques_by_name = dict((c.name, c) for c in conn_unique_constraints)
     conn_indexes_by_name = dict((c.name, c) for c in conn_indexes)
 
     conn_names = dict((c.name, c) for c in
-                    conn_unique_constraints.union(conn_indexes)
-                            if c.name is not None)
+                      conn_unique_constraints.union(conn_indexes)
+                      if c.name is not None)
 
     doubled_constraints = dict(
         (name, (conn_uniques_by_name[name], conn_indexes_by_name[name]))
-        for name in set(conn_uniques_by_name).intersection(conn_indexes_by_name)
+        for name in set(
+            conn_uniques_by_name).intersection(conn_indexes_by_name)
     )
 
     # 6. index things by "column signature", to help with unnamed unique
     # constraints.
     conn_uniques_by_sig = dict((uq.sig, uq) for uq in conn_unique_constraints)
     metadata_uniques_by_sig = dict(
-                            (uq.sig, uq) for uq in metadata_unique_constraints)
+        (uq.sig, uq) for uq in metadata_unique_constraints)
     metadata_indexes_by_sig = dict(
-                            (ix.sig, ix) for ix in metadata_indexes)
-    unnamed_metadata_uniques = dict((uq.sig, uq) for uq in
-                            metadata_unique_constraints if uq.name is None)
+        (ix.sig, ix) for ix in metadata_indexes)
+    unnamed_metadata_uniques = dict(
+        (uq.sig, uq) for uq in
+        metadata_unique_constraints if uq.name is None)
 
     # assumptions:
     # 1. a unique constraint or an index from the connection *always*
@@ -301,10 +319,10 @@ def _compare_indexes_and_uniques(schema, tname, object_filters, conn_table,
         if obj.is_index:
             diffs.append(("add_index", obj.const))
             log.info("Detected added index '%s' on %s",
-                obj.name, ', '.join([
-                    "'%s'" % obj.column_names
-                    ])
-            )
+                     obj.name, ', '.join([
+                         "'%s'" % obj.column_names
+                     ])
+                     )
         else:
             if not supports_unique_constraints:
                 # can't report unique indexes as added if we don't
@@ -315,10 +333,10 @@ def _compare_indexes_and_uniques(schema, tname, object_filters, conn_table,
                 return
             diffs.append(("add_constraint", obj.const))
             log.info("Detected added unique constraint '%s' on %s",
-                obj.name, ', '.join([
-                    "'%s'" % obj.column_names
-                    ])
-            )
+                     obj.name, ', '.join([
+                         "'%s'" % obj.column_names
+                     ])
+                     )
 
     def obj_removed(obj):
         if obj.is_index:
@@ -333,20 +351,20 @@ def _compare_indexes_and_uniques(schema, tname, object_filters, conn_table,
         else:
             diffs.append(("remove_constraint", obj.const))
             log.info("Detected removed unique constraint '%s' on '%s'",
-                obj.name, tname
-            )
+                     obj.name, tname
+                     )
 
     def obj_changed(old, new, msg):
         if old.is_index:
             log.info("Detected changed index '%s' on '%s':%s",
-                    old.name, tname, ', '.join(msg)
-                )
+                     old.name, tname, ', '.join(msg)
+                     )
             diffs.append(("remove_index", old.const))
             diffs.append(("add_index", new.const))
         else:
             log.info("Detected changed unique constraint '%s' on '%s':%s",
-                    old.name, tname, ', '.join(msg)
-                )
+                     old.name, tname, ', '.join(msg)
+                     )
             diffs.append(("remove_constraint", old.const))
             diffs.append(("add_constraint", new.const))
 
@@ -354,7 +372,6 @@ def _compare_indexes_and_uniques(schema, tname, object_filters, conn_table,
         obj = metadata_names[added_name]
         obj_added(obj)
 
-
     for existing_name in sorted(set(metadata_names).intersection(conn_names)):
         metadata_obj = metadata_names[existing_name]
 
@@ -384,14 +401,13 @@ def _compare_indexes_and_uniques(schema, tname, object_filters, conn_table,
             if msg:
                 obj_changed(conn_obj, metadata_obj, msg)
 
-
     for removed_name in sorted(set(conn_names).difference(metadata_names)):
         conn_obj = conn_names[removed_name]
         if not conn_obj.is_index and conn_obj.sig in unnamed_metadata_uniques:
             continue
         elif removed_name in doubled_constraints:
             if conn_obj.sig not in metadata_indexes_by_sig and \
-                conn_obj.sig not in metadata_uniques_by_sig:
+                    conn_obj.sig not in metadata_uniques_by_sig:
                 conn_uq, conn_idx = doubled_constraints[removed_name]
                 obj_removed(conn_uq)
                 obj_removed(conn_idx)
@@ -404,8 +420,8 @@ def _compare_indexes_and_uniques(schema, tname, object_filters, conn_table,
 
 
 def _compare_nullable(schema, tname, cname, conn_col,
-                            metadata_col_nullable, diffs,
-                            autogen_context):
+                      metadata_col_nullable, diffs,
+                      autogen_context):
     conn_col_nullable = conn_col.nullable
     if conn_col_nullable is not metadata_col_nullable:
         diffs.append(
@@ -418,24 +434,25 @@ def _compare_nullable(schema, tname, cname, conn_col,
                 metadata_col_nullable),
         )
         log.info("Detected %s on column '%s.%s'",
-            "NULL" if metadata_col_nullable else "NOT NULL",
-            tname,
-            cname
-        )
+                 "NULL" if metadata_col_nullable else "NOT NULL",
+                 tname,
+                 cname
+                 )
+
 
 def _compare_type(schema, tname, cname, conn_col,
-                            metadata_col, diffs,
-                            autogen_context):
+                  metadata_col, diffs,
+                  autogen_context):
 
     conn_type = conn_col.type
     metadata_type = metadata_col.type
     if conn_type._type_affinity is sqltypes.NullType:
         log.info("Couldn't determine database type "
-                    "for column '%s.%s'", tname, cname)
+                 "for column '%s.%s'", tname, cname)
         return
     if metadata_type._type_affinity is sqltypes.NullType:
         log.info("Column '%s.%s' has no type within "
-                        "the model; can't compare", tname, cname)
+                 "the model; can't compare", tname, cname)
         return
 
     isdiff = autogen_context['context']._compare_type(conn_col, metadata_col)
@@ -444,40 +461,42 @@ def _compare_type(schema, tname, cname, conn_col,
 
         diffs.append(
             ("modify_type", schema, tname, cname,
-                    {
-                        "existing_nullable": conn_col.nullable,
-                        "existing_server_default": conn_col.server_default,
-                    },
-                    conn_type,
-                    metadata_type),
+             {
+                 "existing_nullable": conn_col.nullable,
+                 "existing_server_default": conn_col.server_default,
+             },
+             conn_type,
+             metadata_type),
         )
         log.info("Detected type change from %r to %r on '%s.%s'",
-            conn_type, metadata_type, tname, cname
-        )
+                 conn_type, metadata_type, tname, cname
+                 )
+
 
 def _render_server_default_for_compare(metadata_default,
-                                        metadata_col, autogen_context):
+                                       metadata_col, autogen_context):
     return _render_server_default(
-                    metadata_default, autogen_context,
-                    repr_=metadata_col.type._type_affinity is sqltypes.String)
+        metadata_default, autogen_context,
+        repr_=metadata_col.type._type_affinity is sqltypes.String)
+
 
 def _compare_server_default(schema, tname, cname, conn_col, metadata_col,
-                                diffs, autogen_context):
+                            diffs, autogen_context):
 
     metadata_default = metadata_col.server_default
     conn_col_default = conn_col.server_default
     if conn_col_default is None and metadata_default is None:
         return False
     rendered_metadata_default = _render_server_default_for_compare(
-                    metadata_default, metadata_col, autogen_context)
+        metadata_default, metadata_col, autogen_context)
 
     rendered_conn_default = conn_col.server_default.arg.text \
-                            if conn_col.server_default else None
+        if conn_col.server_default else None
     isdiff = autogen_context['context']._compare_server_default(
-                        conn_col, metadata_col,
-                        rendered_metadata_default,
-                        rendered_conn_default
-                    )
+        conn_col, metadata_col,
+        rendered_metadata_default,
+        rendered_conn_default
+    )
     if isdiff:
         conn_col_default = rendered_conn_default
         diffs.append(
@@ -490,6 +509,6 @@ def _compare_server_default(schema, tname, cname, conn_col, metadata_col,
                 metadata_default),
         )
         log.info("Detected server default on column '%s.%s'",
-            tname,
-            cname
-        )
+                 tname,
+                 cname
+                 )
