@@ -14,11 +14,14 @@ from sqlalchemy.sql import and_, column, literal_column
 from . import patch
 
 from alembic import autogenerate, util, compat
-from . import eq_, eq_ignore_whitespace, requires_092, requires_09, requires_094
+from . import eq_, eq_ignore_whitespace, requires_092, \
+    requires_09, requires_094
 
 py3k = sys.version_info >= (3, )
 
+
 class AutogenRenderTest(TestCase):
+
     """test individual directives"""
 
     @classmethod
@@ -38,17 +41,16 @@ class AutogenRenderTest(TestCase):
             'dialect': postgresql.dialect()
         }
 
-
     def test_render_add_index(self):
         """
         autogenerate.render._add_index
         """
         m = MetaData()
         t = Table('test', m,
-            Column('id', Integer, primary_key=True),
-            Column('active', Boolean()),
-            Column('code', String(255)),
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('active', Boolean()),
+                  Column('code', String(255)),
+                  )
         idx = Index('test_active_code_idx', t.c.active, t.c.code)
         eq_ignore_whitespace(
             autogenerate.render._add_index(idx, self.autogen_context),
@@ -62,11 +64,11 @@ class AutogenRenderTest(TestCase):
         """
         m = MetaData()
         t = Table('test', m,
-            Column('id', Integer, primary_key=True),
-            Column('active', Boolean()),
-            Column('code', String(255)),
-            schema='CamelSchema'
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('active', Boolean()),
+                  Column('code', String(255)),
+                  schema='CamelSchema'
+                  )
         idx = Index('test_active_code_idx', t.c.active, t.c.code)
         eq_ignore_whitespace(
             autogenerate.render._add_index(idx, self.autogen_context),
@@ -79,24 +81,26 @@ class AutogenRenderTest(TestCase):
 
         m = MetaData()
         t = Table('t', m,
-            Column('x', String),
-            Column('y', String)
-            )
+                  Column('x', String),
+                  Column('y', String)
+                  )
 
         idx = Index('foo_idx', t.c.x, t.c.y,
-                            postgresql_where=(t.c.y == 'something'))
+                    postgresql_where=(t.c.y == 'something'))
 
         if compat.sqla_08:
             eq_ignore_whitespace(
                 autogenerate.render._add_index(idx, autogen_context),
-                """op.create_index('foo_idx', 't', ['x', 'y'], unique=False, """
-                    """postgresql_where=sa.text("t.y = 'something'"))"""
+                """op.create_index('foo_idx', 't', \
+['x', 'y'], unique=False, """
+                """postgresql_where=sa.text("t.y = 'something'"))"""
             )
         else:
             eq_ignore_whitespace(
                 autogenerate.render._add_index(idx, autogen_context),
-                """op.create_index('foo_idx', 't', ['x', 'y'], unique=False, """
-                    """postgresql_where=sa.text('t.y = %(y_1)s'))"""
+                """op.create_index('foo_idx', 't', ['x', 'y'], \
+unique=False, """
+                """postgresql_where=sa.text('t.y = %(y_1)s'))"""
             )
 
     # def test_render_add_index_func(self):
@@ -110,7 +114,8 @@ class AutogenRenderTest(TestCase):
     #         Column('active', Boolean()),
     #         Column('code', String(255)),
     #     )
-    #     idx = Index('test_active_lower_code_idx', t.c.active, func.lower(t.c.code))
+    #     idx = Index(
+    #       'test_active_lower_code_idx', t.c.active, func.lower(t.c.code))
     #     eq_ignore_whitespace(
     #         autogenerate.render._add_index(idx, self.autogen_context),
     #         ""
@@ -122,10 +127,10 @@ class AutogenRenderTest(TestCase):
         """
         m = MetaData()
         t = Table('test', m,
-            Column('id', Integer, primary_key=True),
-            Column('active', Boolean()),
-            Column('code', String(255)),
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('active', Boolean()),
+                  Column('code', String(255)),
+                  )
         idx = Index('test_active_code_idx', t.c.active, t.c.code)
         eq_ignore_whitespace(
             autogenerate.render._drop_index(idx, self.autogen_context),
@@ -138,16 +143,16 @@ class AutogenRenderTest(TestCase):
         """
         m = MetaData()
         t = Table('test', m,
-            Column('id', Integer, primary_key=True),
-            Column('active', Boolean()),
-            Column('code', String(255)),
-            schema='CamelSchema'
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('active', Boolean()),
+                  Column('code', String(255)),
+                  schema='CamelSchema'
+                  )
         idx = Index('test_active_code_idx', t.c.active, t.c.code)
         eq_ignore_whitespace(
             autogenerate.render._drop_index(idx, self.autogen_context),
             "op.drop_index('test_active_code_idx', " +
-                          "table_name='test', schema='CamelSchema')"
+            "table_name='test', schema='CamelSchema')"
         )
 
     def test_add_unique_constraint(self):
@@ -156,13 +161,14 @@ class AutogenRenderTest(TestCase):
         """
         m = MetaData()
         t = Table('test', m,
-            Column('id', Integer, primary_key=True),
-            Column('active', Boolean()),
-            Column('code', String(255)),
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('active', Boolean()),
+                  Column('code', String(255)),
+                  )
         uq = UniqueConstraint(t.c.code, name='uq_test_code')
         eq_ignore_whitespace(
-            autogenerate.render._add_unique_constraint(uq, self.autogen_context),
+            autogenerate.render._add_unique_constraint(
+                uq, self.autogen_context),
             "op.create_unique_constraint('uq_test_code', 'test', ['code'])"
         )
 
@@ -172,15 +178,17 @@ class AutogenRenderTest(TestCase):
         """
         m = MetaData()
         t = Table('test', m,
-            Column('id', Integer, primary_key=True),
-            Column('active', Boolean()),
-            Column('code', String(255)),
-            schema='CamelSchema'
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('active', Boolean()),
+                  Column('code', String(255)),
+                  schema='CamelSchema'
+                  )
         uq = UniqueConstraint(t.c.code, name='uq_test_code')
         eq_ignore_whitespace(
-            autogenerate.render._add_unique_constraint(uq, self.autogen_context),
-            "op.create_unique_constraint('uq_test_code', 'test', ['code'], schema='CamelSchema')"
+            autogenerate.render._add_unique_constraint(
+                uq, self.autogen_context),
+            "op.create_unique_constraint('uq_test_code', 'test', "
+            "['code'], schema='CamelSchema')"
         )
 
     def test_drop_constraint(self):
@@ -189,10 +197,10 @@ class AutogenRenderTest(TestCase):
         """
         m = MetaData()
         t = Table('test', m,
-            Column('id', Integer, primary_key=True),
-            Column('active', Boolean()),
-            Column('code', String(255)),
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('active', Boolean()),
+                  Column('code', String(255)),
+                  )
         uq = UniqueConstraint(t.c.code, name='uq_test_code')
         eq_ignore_whitespace(
             autogenerate.render._drop_constraint(uq, self.autogen_context),
@@ -205,11 +213,11 @@ class AutogenRenderTest(TestCase):
         """
         m = MetaData()
         t = Table('test', m,
-            Column('id', Integer, primary_key=True),
-            Column('active', Boolean()),
-            Column('code', String(255)),
-            schema='CamelSchema'
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('active', Boolean()),
+                  Column('code', String(255)),
+                  schema='CamelSchema'
+                  )
         uq = UniqueConstraint(t.c.code, name='uq_test_code')
         eq_ignore_whitespace(
             autogenerate.render._drop_constraint(uq, self.autogen_context),
@@ -219,14 +227,14 @@ class AutogenRenderTest(TestCase):
     def test_render_table_upgrade(self):
         m = MetaData()
         t = Table('test', m,
-            Column('id', Integer, primary_key=True),
-            Column('name', Unicode(255)),
-            Column("address_id", Integer, ForeignKey("address.id")),
-            Column("timestamp", DATETIME, server_default="NOW()"),
-            Column("amount", Numeric(5, 2)),
-            UniqueConstraint("name", name="uq_name"),
-            UniqueConstraint("timestamp"),
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('name', Unicode(255)),
+                  Column("address_id", Integer, ForeignKey("address.id")),
+                  Column("timestamp", DATETIME, server_default="NOW()"),
+                  Column("amount", Numeric(5, 2)),
+                  UniqueConstraint("name", name="uq_name"),
+                  UniqueConstraint("timestamp"),
+                  )
         eq_ignore_whitespace(
             autogenerate.render._add_table(t, self.autogen_context),
             "op.create_table('test',"
@@ -234,9 +242,10 @@ class AutogenRenderTest(TestCase):
             "sa.Column('name', sa.Unicode(length=255), nullable=True),"
             "sa.Column('address_id', sa.Integer(), nullable=True),"
             "sa.Column('timestamp', sa.DATETIME(), "
-                "server_default='NOW()', "
-                "nullable=True),"
-            "sa.Column('amount', sa.Numeric(precision=5, scale=2), nullable=True),"
+            "server_default='NOW()', "
+            "nullable=True),"
+            "sa.Column('amount', sa.Numeric(precision=5, scale=2), "
+            "nullable=True),"
             "sa.ForeignKeyConstraint(['address_id'], ['address.id'], ),"
             "sa.PrimaryKeyConstraint('id'),"
             "sa.UniqueConstraint('name', name='uq_name'),"
@@ -247,10 +256,10 @@ class AutogenRenderTest(TestCase):
     def test_render_table_w_schema(self):
         m = MetaData()
         t = Table('test', m,
-            Column('id', Integer, primary_key=True),
-            Column('q', Integer, ForeignKey('address.id')),
-            schema='foo'
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('q', Integer, ForeignKey('address.id')),
+                  schema='foo'
+                  )
         eq_ignore_whitespace(
             autogenerate.render._add_table(t, self.autogen_context),
             "op.create_table('test',"
@@ -299,9 +308,9 @@ class AutogenRenderTest(TestCase):
     def test_render_table_w_fk_schema(self):
         m = MetaData()
         t = Table('test', m,
-            Column('id', Integer, primary_key=True),
-            Column('q', Integer, ForeignKey('foo.address.id')),
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('q', Integer, ForeignKey('foo.address.id')),
+                  )
         eq_ignore_whitespace(
             autogenerate.render._add_table(t, self.autogen_context),
             "op.create_table('test',"
@@ -315,11 +324,13 @@ class AutogenRenderTest(TestCase):
     def test_render_table_w_metadata_schema(self):
         m = MetaData(schema="foo")
         t = Table('test', m,
-            Column('id', Integer, primary_key=True),
-            Column('q', Integer, ForeignKey('address.id')),
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('q', Integer, ForeignKey('address.id')),
+                  )
         eq_ignore_whitespace(
-            re.sub(r"u'", "'", autogenerate.render._add_table(t, self.autogen_context)),
+            re.sub(
+                r"u'", "'",
+                autogenerate.render._add_table(t, self.autogen_context)),
             "op.create_table('test',"
             "sa.Column('id', sa.Integer(), nullable=False),"
             "sa.Column('q', sa.Integer(), nullable=True),"
@@ -332,9 +343,9 @@ class AutogenRenderTest(TestCase):
     def test_render_table_w_metadata_schema_override(self):
         m = MetaData(schema="foo")
         t = Table('test', m,
-            Column('id', Integer, primary_key=True),
-            Column('q', Integer, ForeignKey('bar.address.id')),
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('q', Integer, ForeignKey('bar.address.id')),
+                  )
         eq_ignore_whitespace(
             autogenerate.render._add_table(t, self.autogen_context),
             "op.create_table('test',"
@@ -349,10 +360,10 @@ class AutogenRenderTest(TestCase):
     def test_render_addtl_args(self):
         m = MetaData()
         t = Table('test', m,
-            Column('id', Integer, primary_key=True),
-            Column('q', Integer, ForeignKey('bar.address.id')),
-            sqlite_autoincrement=True, mysql_engine="InnoDB"
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('q', Integer, ForeignKey('bar.address.id')),
+                  sqlite_autoincrement=True, mysql_engine="InnoDB"
+                  )
         eq_ignore_whitespace(
             autogenerate.render._add_table(t, self.autogen_context),
             "op.create_table('test',"
@@ -366,7 +377,7 @@ class AutogenRenderTest(TestCase):
     def test_render_drop_table(self):
         eq_(
             autogenerate.render._drop_table(Table("sometable", MetaData()),
-                        self.autogen_context),
+                                            self.autogen_context),
             "op.drop_table('sometable')"
         )
 
@@ -384,7 +395,8 @@ class AutogenRenderTest(TestCase):
 
         eq_ignore_whitespace(
             autogenerate.render._add_table(t, self.autogen_context),
-            "op.create_table('test',sa.Column('x', sa.Boolean(), nullable=True))"
+            "op.create_table('test',"
+            "sa.Column('x', sa.Boolean(), nullable=True))"
         )
 
     def test_render_empty_pk_vs_nonempty_pk(self):
@@ -407,26 +419,26 @@ class AutogenRenderTest(TestCase):
     def test_render_add_column(self):
         eq_(
             autogenerate.render._add_column(
-                    None, "foo", Column("x", Integer, server_default="5"),
-                        self.autogen_context),
+                None, "foo", Column("x", Integer, server_default="5"),
+                self.autogen_context),
             "op.add_column('foo', sa.Column('x', sa.Integer(), "
-                "server_default='5', nullable=True))"
+            "server_default='5', nullable=True))"
         )
 
     def test_render_add_column_w_schema(self):
         eq_(
             autogenerate.render._add_column(
-                    "foo", "bar", Column("x", Integer, server_default="5"),
-                        self.autogen_context),
+                "foo", "bar", Column("x", Integer, server_default="5"),
+                self.autogen_context),
             "op.add_column('bar', sa.Column('x', sa.Integer(), "
-                "server_default='5', nullable=True), schema='foo')"
+            "server_default='5', nullable=True), schema='foo')"
         )
 
     def test_render_drop_column(self):
         eq_(
             autogenerate.render._drop_column(
-                    None, "foo", Column("x", Integer, server_default="5"),
-                        self.autogen_context),
+                None, "foo", Column("x", Integer, server_default="5"),
+                self.autogen_context),
 
             "op.drop_column('foo', 'x')"
         )
@@ -434,8 +446,8 @@ class AutogenRenderTest(TestCase):
     def test_render_drop_column_w_schema(self):
         eq_(
             autogenerate.render._drop_column(
-                    "foo", "bar", Column("x", Integer, server_default="5"),
-                        self.autogen_context),
+                "foo", "bar", Column("x", Integer, server_default="5"),
+                self.autogen_context),
 
             "op.drop_column('bar', 'x', schema='foo')"
         )
@@ -444,35 +456,35 @@ class AutogenRenderTest(TestCase):
         eq_(
             autogenerate.render._render_server_default(
                 "nextval('group_to_perm_group_to_perm_id_seq'::regclass)",
-                    self.autogen_context),
+                self.autogen_context),
             '"nextval(\'group_to_perm_group_to_perm_id_seq\'::regclass)"'
         )
 
     def test_render_col_with_server_default(self):
         c = Column('updated_at', TIMESTAMP(),
-                server_default='TIMEZONE("utc", CURRENT_TIMESTAMP)',
-                nullable=False)
+                   server_default='TIMEZONE("utc", CURRENT_TIMESTAMP)',
+                   nullable=False)
         result = autogenerate.render._render_column(
-                    c, self.autogen_context
-                )
+            c, self.autogen_context
+        )
         eq_(
             result,
             'sa.Column(\'updated_at\', sa.TIMESTAMP(), '
-                'server_default=\'TIMEZONE("utc", CURRENT_TIMESTAMP)\', '
-                'nullable=False)'
+            'server_default=\'TIMEZONE("utc", CURRENT_TIMESTAMP)\', '
+            'nullable=False)'
         )
 
     def test_render_col_autoinc_false_mysql(self):
         c = Column('some_key', Integer, primary_key=True, autoincrement=False)
         Table('some_table', MetaData(), c)
         result = autogenerate.render._render_column(
-                    c, self.autogen_context
-                )
+            c, self.autogen_context
+        )
         eq_(
             result,
             'sa.Column(\'some_key\', sa.Integer(), '
-                'autoincrement=False, '
-                'nullable=False)'
+            'autoincrement=False, '
+            'nullable=False)'
         )
 
     def test_render_custom(self):
@@ -493,14 +505,14 @@ class AutogenRenderTest(TestCase):
         }}
 
         t = Table('t', MetaData(),
-                Column('x', Integer),
-                Column('y', Integer),
-                PrimaryKeyConstraint('x'),
-                ForeignKeyConstraint(['x'], ['y'])
-            )
+                  Column('x', Integer),
+                  Column('y', Integer),
+                  PrimaryKeyConstraint('x'),
+                  ForeignKeyConstraint(['x'], ['y'])
+                  )
         result = autogenerate.render._add_table(
-                    t, autogen_context
-                )
+            t, autogen_context
+        )
         eq_(
             result, """sa.create_table('t',
 col(x),
@@ -510,32 +522,32 @@ render:primary_key\n)"""
     def test_render_modify_type(self):
         eq_ignore_whitespace(
             autogenerate.render._modify_col(
-                        "sometable", "somecolumn",
-                        self.autogen_context,
-                        type_=CHAR(10), existing_type=CHAR(20)),
+                "sometable", "somecolumn",
+                self.autogen_context,
+                type_=CHAR(10), existing_type=CHAR(20)),
             "op.alter_column('sometable', 'somecolumn', "
-                "existing_type=sa.CHAR(length=20), type_=sa.CHAR(length=10))"
+            "existing_type=sa.CHAR(length=20), type_=sa.CHAR(length=10))"
         )
 
     def test_render_modify_type_w_schema(self):
         eq_ignore_whitespace(
             autogenerate.render._modify_col(
-                        "sometable", "somecolumn",
-                        self.autogen_context,
-                        type_=CHAR(10), existing_type=CHAR(20),
-                        schema='foo'),
+                "sometable", "somecolumn",
+                self.autogen_context,
+                type_=CHAR(10), existing_type=CHAR(20),
+                schema='foo'),
             "op.alter_column('sometable', 'somecolumn', "
-                "existing_type=sa.CHAR(length=20), type_=sa.CHAR(length=10), "
-                "schema='foo')"
+            "existing_type=sa.CHAR(length=20), type_=sa.CHAR(length=10), "
+            "schema='foo')"
         )
 
     def test_render_modify_nullable(self):
         eq_ignore_whitespace(
             autogenerate.render._modify_col(
-                        "sometable", "somecolumn",
-                        self.autogen_context,
-                        existing_type=Integer(),
-                        nullable=True),
+                "sometable", "somecolumn",
+                self.autogen_context,
+                existing_type=Integer(),
+                nullable=True),
             "op.alter_column('sometable', 'somecolumn', "
             "existing_type=sa.Integer(), nullable=True)"
         )
@@ -543,10 +555,10 @@ render:primary_key\n)"""
     def test_render_modify_nullable_w_schema(self):
         eq_ignore_whitespace(
             autogenerate.render._modify_col(
-                        "sometable", "somecolumn",
-                        self.autogen_context,
-                        existing_type=Integer(),
-                        nullable=True, schema='foo'),
+                "sometable", "somecolumn",
+                self.autogen_context,
+                existing_type=Integer(),
+                nullable=True, schema='foo'),
             "op.alter_column('sometable', 'somecolumn', "
             "existing_type=sa.Integer(), nullable=True, schema='foo')"
         )
@@ -561,7 +573,10 @@ render:primary_key\n)"""
             t1.append_constraint(fk)
 
         eq_ignore_whitespace(
-            re.sub(r"u'", "'", autogenerate.render._render_constraint(fk, self.autogen_context)),
+            re.sub(
+                r"u'", "'",
+                autogenerate.render._render_constraint(
+                    fk, self.autogen_context)),
             "sa.ForeignKeyConstraint(['c'], ['t2.c_rem'], onupdate='CASCADE')"
         )
 
@@ -570,7 +585,10 @@ render:primary_key\n)"""
             t1.append_constraint(fk)
 
         eq_ignore_whitespace(
-            re.sub(r"u'", "'", autogenerate.render._render_constraint(fk, self.autogen_context)),
+            re.sub(
+                r"u'", "'",
+                autogenerate.render._render_constraint(
+                    fk, self.autogen_context)),
             "sa.ForeignKeyConstraint(['c'], ['t2.c_rem'], ondelete='CASCADE')"
         )
 
@@ -578,7 +596,10 @@ render:primary_key\n)"""
         if not util.sqla_08:
             t1.append_constraint(fk)
         eq_ignore_whitespace(
-            re.sub(r"u'", "'", autogenerate.render._render_constraint(fk, self.autogen_context)),
+            re.sub(
+                r"u'", "'",
+                autogenerate.render._render_constraint(
+                    fk, self.autogen_context)),
             "sa.ForeignKeyConstraint(['c'], ['t2.c_rem'], deferrable=True)"
         )
 
@@ -586,21 +607,28 @@ render:primary_key\n)"""
         if not util.sqla_08:
             t1.append_constraint(fk)
         eq_ignore_whitespace(
-            re.sub(r"u'", "'", autogenerate.render._render_constraint(fk, self.autogen_context)),
+            re.sub(
+                r"u'", "'",
+                autogenerate.render._render_constraint(
+                    fk, self.autogen_context)),
             "sa.ForeignKeyConstraint(['c'], ['t2.c_rem'], initially='XYZ')"
         )
 
     def test_render_fk_constraint_use_alter(self):
         m = MetaData()
         Table('t', m, Column('c', Integer))
-        t2 = Table('t2', m, Column('c_rem', Integer,
-                                ForeignKey('t.c', name="fk1", use_alter=True)))
+        t2 = Table(
+            't2', m,
+            Column(
+                'c_rem', Integer,
+                ForeignKey('t.c', name="fk1", use_alter=True)))
         const = list(t2.foreign_keys)[0].constraint
 
         eq_ignore_whitespace(
-            autogenerate.render._render_constraint(const, self.autogen_context),
+            autogenerate.render._render_constraint(
+                const, self.autogen_context),
             "sa.ForeignKeyConstraint(['c_rem'], ['t.c'], "
-                    "name='fk1', use_alter=True)"
+            "name='fk1', use_alter=True)"
         )
 
     def test_render_fk_constraint_w_metadata_schema(self):
@@ -613,8 +641,12 @@ render:primary_key\n)"""
             t1.append_constraint(fk)
 
         eq_ignore_whitespace(
-            re.sub(r"u'", "'", autogenerate.render._render_constraint(fk, self.autogen_context)),
-            "sa.ForeignKeyConstraint(['c'], ['foo.t2.c_rem'], onupdate='CASCADE')"
+            re.sub(
+                r"u'", "'",
+                autogenerate.render._render_constraint(
+                    fk, self.autogen_context)),
+            "sa.ForeignKeyConstraint(['c'], ['foo.t2.c_rem'], "
+            "onupdate='CASCADE')"
         )
 
     def test_render_check_constraint_literal(self):
@@ -626,7 +658,6 @@ render:primary_key\n)"""
             "sa.CheckConstraint('im a constraint', name='cc1')"
         )
 
-
     def test_render_check_constraint_sqlexpr(self):
         c = column('c')
         five = literal_column('5')
@@ -653,29 +684,27 @@ render:primary_key\n)"""
     def test_render_modify_nullable_w_default(self):
         eq_ignore_whitespace(
             autogenerate.render._modify_col(
-                        "sometable", "somecolumn",
-                        self.autogen_context,
-                        existing_type=Integer(),
-                        existing_server_default="5",
-                        nullable=True),
+                "sometable", "somecolumn",
+                self.autogen_context,
+                existing_type=Integer(),
+                existing_server_default="5",
+                nullable=True),
             "op.alter_column('sometable', 'somecolumn', "
             "existing_type=sa.Integer(), nullable=True, "
             "existing_server_default='5')"
         )
 
-
-
     def test_render_enum(self):
         eq_ignore_whitespace(
             autogenerate.render._repr_type(
-                        Enum("one", "two", "three", name="myenum"),
-                        self.autogen_context),
+                Enum("one", "two", "three", name="myenum"),
+                self.autogen_context),
             "sa.Enum('one', 'two', 'three', name='myenum')"
         )
         eq_ignore_whitespace(
             autogenerate.render._repr_type(
-                        Enum("one", "two", "three"),
-                        self.autogen_context),
+                Enum("one", "two", "three"),
+                self.autogen_context),
             "sa.Enum('one', 'two', 'three')"
         )
 
@@ -696,7 +725,9 @@ render:primary_key\n)"""
 
     def test_repr_user_type_user_prefix_None(self):
         from sqlalchemy.types import UserDefinedType
+
         class MyType(UserDefinedType):
+
             def get_col_spec(self):
                 return "MYTYPE"
 
@@ -717,7 +748,9 @@ render:primary_key\n)"""
 
     def test_repr_user_type_user_prefix_present(self):
         from sqlalchemy.types import UserDefinedType
+
         class MyType(UserDefinedType):
+
             def get_col_spec(self):
                 return "MYTYPE"
 
@@ -755,9 +788,10 @@ render:primary_key\n)"""
             "mysql.VARCHAR(charset='utf8', national=True, length=20)"
         )
         eq_(autogen_context['imports'],
-                set(['from sqlalchemy.dialects import mysql'])
+            set(['from sqlalchemy.dialects import mysql'])
             )
 
+
 class RenderNamingConventionTest(TestCase):
 
     @classmethod
@@ -771,30 +805,30 @@ class RenderNamingConventionTest(TestCase):
             'dialect': postgresql.dialect()
         }
 
-
     def setUp(self):
 
         convention = {
-          "ix": 'ix_%(custom)s_%(column_0_label)s',
-          "uq": "uq_%(custom)s_%(table_name)s_%(column_0_name)s",
-          "ck": "ck_%(custom)s_%(table_name)s",
-          "fk": "fk_%(custom)s_%(table_name)s_%(column_0_name)s_%(referred_table_name)s",
-          "pk": "pk_%(custom)s_%(table_name)s",
-          "custom": lambda const, table: "ct"
+            "ix": 'ix_%(custom)s_%(column_0_label)s',
+            "uq": "uq_%(custom)s_%(table_name)s_%(column_0_name)s",
+            "ck": "ck_%(custom)s_%(table_name)s",
+            "fk": "fk_%(custom)s_%(table_name)s_"
+            "%(column_0_name)s_%(referred_table_name)s",
+            "pk": "pk_%(custom)s_%(table_name)s",
+            "custom": lambda const, table: "ct"
         }
 
         self.metadata = MetaData(
-                            naming_convention=convention
-                        )
+            naming_convention=convention
+        )
 
     def test_schema_type_boolean(self):
         t = Table('t', self.metadata, Column('c', Boolean(name='xyz')))
         eq_ignore_whitespace(
             autogenerate.render._add_column(
-                    None, "t", t.c.c,
-                        self.autogen_context),
+                None, "t", t.c.c,
+                self.autogen_context),
             "op.add_column('t', "
-                "sa.Column('c', sa.Boolean(name='xyz'), nullable=True))"
+            "sa.Column('c', sa.Boolean(name='xyz'), nullable=True))"
         )
 
     def test_explicit_unique_constraint(self):
@@ -804,7 +838,8 @@ class RenderNamingConventionTest(TestCase):
                 UniqueConstraint(t.c.c, deferrable='XYZ'),
                 self.autogen_context
             ),
-            "sa.UniqueConstraint('c', deferrable='XYZ', name=op.f('uq_ct_t_c'))"
+            "sa.UniqueConstraint('c', deferrable='XYZ', "
+            "name=op.f('uq_ct_t_c'))"
         )
 
     def test_explicit_named_unique_constraint(self):
@@ -819,10 +854,10 @@ class RenderNamingConventionTest(TestCase):
 
     def test_render_add_index(self):
         t = Table('test', self.metadata,
-            Column('id', Integer, primary_key=True),
-            Column('active', Boolean()),
-            Column('code', String(255)),
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('active', Boolean()),
+                  Column('code', String(255)),
+                  )
         idx = Index(None, t.c.active, t.c.code)
         eq_ignore_whitespace(
             autogenerate.render._add_index(idx, self.autogen_context),
@@ -832,10 +867,10 @@ class RenderNamingConventionTest(TestCase):
 
     def test_render_drop_index(self):
         t = Table('test', self.metadata,
-            Column('id', Integer, primary_key=True),
-            Column('active', Boolean()),
-            Column('code', String(255)),
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('active', Boolean()),
+                  Column('code', String(255)),
+                  )
         idx = Index(None, t.c.active, t.c.code)
         eq_ignore_whitespace(
             autogenerate.render._drop_index(idx, self.autogen_context),
@@ -844,11 +879,11 @@ class RenderNamingConventionTest(TestCase):
 
     def test_render_add_index_schema(self):
         t = Table('test', self.metadata,
-            Column('id', Integer, primary_key=True),
-            Column('active', Boolean()),
-            Column('code', String(255)),
-            schema='CamelSchema'
-        )
+                  Column('id', Integer, primary_key=True),
+                  Column('active', Boolean()),
+                  Column('code', String(255)),
+                  schema='CamelSchema'
+                  )
         idx = Index(None, t.c.active, t.c.code)
         eq_ignore_whitespace(
             autogenerate.render._add_index(idx, self.autogen_context),
@@ -856,14 +891,13 @@ class RenderNamingConventionTest(TestCase):
             "['active', 'code'], unique=False, schema='CamelSchema')"
         )
 
-
     def test_implicit_unique_constraint(self):
         t = Table('t', self.metadata, Column('c', Integer, unique=True))
         uq = [c for c in t.constraints if isinstance(c, UniqueConstraint)][0]
         eq_ignore_whitespace(
             autogenerate.render._render_unique_constraint(uq,
-                self.autogen_context
-            ),
+                                                          self.autogen_context
+                                                          ),
             "sa.UniqueConstraint('c', name=op.f('uq_ct_t_c'))"
         )
 
@@ -872,15 +906,16 @@ class RenderNamingConventionTest(TestCase):
         eq_ignore_whitespace(
             autogenerate.render._add_table(t, self.autogen_context),
             "op.create_table('t',sa.Column('c', sa.Integer(), nullable=False),"
-                "sa.PrimaryKeyConstraint('c', name=op.f('pk_ct_t')))"
+            "sa.PrimaryKeyConstraint('c', name=op.f('pk_ct_t')))"
         )
 
     def test_inline_ck_constraint(self):
-        t = Table('t', self.metadata, Column('c', Integer), CheckConstraint("c > 5"))
+        t = Table(
+            't', self.metadata, Column('c', Integer), CheckConstraint("c > 5"))
         eq_ignore_whitespace(
             autogenerate.render._add_table(t, self.autogen_context),
             "op.create_table('t',sa.Column('c', sa.Integer(), nullable=True),"
-                "sa.CheckConstraint('c > 5', name=op.f('ck_ct_t')))"
+            "sa.CheckConstraint('c > 5', name=op.f('ck_ct_t')))"
         )
 
     def test_inline_fk(self):
@@ -888,7 +923,8 @@ class RenderNamingConventionTest(TestCase):
         eq_ignore_whitespace(
             autogenerate.render._add_table(t, self.autogen_context),
             "op.create_table('t',sa.Column('c', sa.Integer(), nullable=True),"
-                "sa.ForeignKeyConstraint(['c'], ['q.id'], name=op.f('fk_ct_t_c_q')))"
+            "sa.ForeignKeyConstraint(['c'], ['q.id'], "
+            "name=op.f('fk_ct_t_c_q')))"
         )
 
     def test_render_check_constraint_renamed(self):
@@ -902,7 +938,8 @@ class RenderNamingConventionTest(TestCase):
         used.
 
         """
-        m1 = MetaData(naming_convention={"ck": "ck_%(table_name)s_%(constraint_name)s"})
+        m1 = MetaData(naming_convention={
+            "ck": "ck_%(table_name)s_%(constraint_name)s"})
         ck = CheckConstraint("im a constraint", name="cc1")
         Table('t', m1, Column('x'), ck)
 
