@@ -1,7 +1,7 @@
 from unittest import TestCase
 
 from sqlalchemy import DateTime, MetaData, Table, Column, text, Integer, \
-        String, Interval
+    String, Interval
 from sqlalchemy.dialects.postgresql import ARRAY
 from sqlalchemy.schema import DefaultClause
 from sqlalchemy.engine.reflection import Inspector
@@ -13,10 +13,12 @@ from alembic import command, util
 from alembic.migration import MigrationContext
 from alembic.script import ScriptDirectory
 from . import db_for_dialect, eq_, staging_env, \
-            clear_staging_env, _no_sql_testing_config,\
-            capture_context_buffer, requires_09, write_script
+    clear_staging_env, _no_sql_testing_config,\
+    capture_context_buffer, requires_09, write_script
+
 
 class PGOfflineEnumTest(TestCase):
+
     def setUp(self):
         staging_env()
         self.cfg = cfg = _no_sql_testing_config()
@@ -29,7 +31,6 @@ class PGOfflineEnumTest(TestCase):
     def tearDown(self):
         clear_staging_env()
 
-
     def _inline_enum_script(self):
         write_script(self.script, self.rid, """
 revision = '%s'
@@ -75,7 +76,8 @@ def downgrade():
         self._inline_enum_script()
         with capture_context_buffer() as buf:
             command.upgrade(self.cfg, self.rid, sql=True)
-        assert "CREATE TYPE pgenum AS ENUM ('one', 'two', 'three')" in buf.getvalue()
+        assert "CREATE TYPE pgenum AS "\
+            "ENUM ('one', 'two', 'three')" in buf.getvalue()
         assert "CREATE TABLE sometable (\n    data pgenum\n)" in buf.getvalue()
 
     def test_offline_inline_enum_drop(self):
@@ -91,7 +93,8 @@ def downgrade():
         self._distinct_enum_script()
         with capture_context_buffer() as buf:
             command.upgrade(self.cfg, self.rid, sql=True)
-        assert "CREATE TYPE pgenum AS ENUM ('one', 'two', 'three')" in buf.getvalue()
+        assert "CREATE TYPE pgenum AS ENUM "\
+            "('one', 'two', 'three')" in buf.getvalue()
         assert "CREATE TABLE sometable (\n    data pgenum\n)" in buf.getvalue()
 
     def test_offline_distinct_enum_drop(self):
@@ -103,6 +106,7 @@ def downgrade():
 
 
 class PostgresqlInlineLiteralTest(TestCase):
+
     @classmethod
     def setup_class(cls):
         cls.bind = db_for_dialect("postgresql")
@@ -140,11 +144,14 @@ class PostgresqlInlineLiteralTest(TestCase):
             execution_options={'no_parameters': True}
         )
         eq_(
-            self.conn.execute("select count(*) from tab where col='new data'").scalar(),
+            self.conn.execute(
+                "select count(*) from tab where col='new data'").scalar(),
             1,
         )
 
+
 class PostgresqlDefaultCompareTest(TestCase):
+
     @classmethod
     def setup_class(cls):
         cls.bind = db_for_dialect("postgresql")
@@ -180,19 +187,19 @@ class PostgresqlDefaultCompareTest(TestCase):
             alternate = orig_default
 
         t1 = Table("test", self.metadata,
-            Column("somecol", type_, server_default=orig_default))
+                   Column("somecol", type_, server_default=orig_default))
         t2 = Table("test", MetaData(),
-            Column("somecol", type_, server_default=alternate))
+                   Column("somecol", type_, server_default=alternate))
 
         t1.create(self.bind)
 
         insp = Inspector.from_engine(self.bind)
         cols = insp.get_columns(t1.name)
         insp_col = Column("somecol", cols[0]['type'],
-                                server_default=text(cols[0]['default']))
+                          server_default=text(cols[0]['default']))
         diffs = []
         _compare_server_default(None, "test", "somecol", insp_col,
-                t2.c.somecol, diffs, self.autogen_context)
+                                t2.c.somecol, diffs, self.autogen_context)
         eq_(bool(diffs), diff_expected)
 
     def _compare_default(
@@ -284,11 +291,11 @@ class PostgresqlDefaultCompareTest(TestCase):
     def test_primary_key_skip(self):
         """Test that SERIAL cols are just skipped"""
         t1 = Table("sometable", self.metadata,
-            Column("id", Integer, primary_key=True)
-        )
+                   Column("id", Integer, primary_key=True)
+                   )
         t2 = Table("sometable", MetaData(),
-            Column("id", Integer, primary_key=True)
-        )
+                   Column("id", Integer, primary_key=True)
+                   )
         assert not self._compare_default(
             t1, t2, t2.c.id, ""
         )
